#
# 	Loren Williams, Georgia Tech
# 	pymol script for hemoglobin (oxy)
#   I had to use symmetry to 
#	generate the biological unit (tetramer).
#
## Header: General Commands ##
# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
# set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 3
set cartoon_gap_cutoff = 0
## End of Header: General Commands ##
#
Chains A and C are alpha
Chains B and D are beta
#---------------------------------------------oxy_hemoglobin

load files/oxy_hemoglobin_2DN1.pdb, temp1
remove resn hoh

#-form the biological unit
symexp s_, temp1, temp1, 10
create temp2, s_05000000
delete s_*

alter (temp2 and chain A), chain='C'
alter (temp2 and chain B), chain='D'
create O2_Hb, temp1 or temp2

delete temp1
delete temp2

hide everything 
show cartoon, (chain A or chain B or chain C or chain D) and O2_Hb


# show the hemes with Fe and O2
create hem1, resn hem
create O2, resn oxy
create his, (resi 87 and resn his) or (resi 92 and resn his)
create pocket, ((resi 43 or resi 58 or resi 62) and (chain A or chain C)) or ((resi 42 or resi 63 or resi 67) and (chain B or chain D))
create heme, hem1 or O2 or his or pocket
delete hem1 or O2 or his or pocket
show sticks, heme

label ((chain A or chain C) and resi 87 and name CG), "Proximal His"
label ((chain A or chain C) and resi 58 and name CG), "Distal His"
label ((chain B or chain D) and resi 92 and name CG), "Proximal His"
label ((chain B or chain D) and resi 63 and name CG), "Distal His"
set label_size, -0.8


# HELIX    1   1 SER A    3  GLY A   18  1                                  16    
# HELIX    2   2 HIS A   20  PHE A   36  1                                  17    # 
# HELIX    3   3 PRO A   37  PHE A   43  5                                   7    
# HELIX    4   4 SER A   52  HIS A   72  1                                  21    
# HELIX    5   5 ASP A   75  LEU A   80  1                                   6    
# HELIX    6   6 LEU A   80  LYS A   90  1                                  11    
# HELIX    7   7 ASP A   94  LEU A  113  1                                  20    
# HELIX    8   8 THR A  118  THR A  137  1                                  20    


create Helix_A1, resi 3-10 and (chain A or chain C) and O2_Hb
create Helix_A2, resi 11-18 and (chain A or chain C) and O2_Hb
create Helix_B, resi 20-36 and (chain A or chain C) and O2_Hb
#create Helix_C, resi 34-38 and (chain A or chain C) and O2_Hb
create Helix_D, resi 37-43 and (chain A or chain C) and O2_Hb
create Helix_E, resi 52-72 and (chain A or chain C) and O2_Hb
create Helix_F1, resi 75-80 and (chain A or chain C) and O2_Hb
create Helix_F2, resi 80-90 and (chain A or chain C) and O2_Hb
create Helix_G, resi 94-113 and (chain A or chain C) and O2_Hb
create Helix_H, resi 118-137 and (chain A or chain C) and O2_Hb

# HELIX    9   9 THR B    4  GLY B   16  1                                  13    
# HELIX   10  10 GLU B   22  TYR B   35  1                                  14    
# HELIX   11  11 PRO B   36  GLY B   46  5                                  11    
# HELIX   12  12 THR B   50  ASN B   57  1                                   8    
# HELIX   13  13 ASN B   57  ALA B   76  1                                  20    
# HELIX   14  14 ASN B   80  PHE B   85  1                                   6    
# HELIX   15  15 PHE B   85  ASP B   94  1                                  10    
# HELIX   16  16 PRO B  100  GLY B  119  1                                  20    
# HELIX   17  17 LYS B  120  PHE B  122  5                                   3    
# HELIX   18  18 THR B  123  ALA B  142  1                                  20    
# HELIX   19  19 HIS B  143  HIS B  146  5                                   4    



create Helix2_A, resi 2-16 and (chain B or chain D) and O2_Hb
create Helix2_B, resi 20-35 and (chain B or chain D) and O2_Hb
create Helix2_C, resi 36-41 and (chain B or chain D) and O2_Hb
create Helix2_D, resi 41-46 and (chain B or chain D) and O2_Hb
create Helix2_E1, resi 50-57 and (chain B or chain D) and O2_Hb
create Helix2_E2, resi 60-76 and (chain B or chain D) and O2_Hb
create Helix2_F1, resi 81-86 and (chain B or chain D) and O2_Hb
create Helix2_F2, resi 86-94 and (chain B or chain D) and O2_Hb
create Helix2_G, resi 94-117 and (chain B or chain D) and O2_Hb
create Helix2_H, resi 125-143 and (chain B or chain D) and O2_Hb

set cartoon_cylindrical_helices,1, Helix_*
set cartoon_cylindrical_helices,1, Helix2_*
set cartoon_helix_radius, 1.5
set cartoon_transparency, 0.3, helix*
set cartoon_fancy_helices, 1

load files/deoxy_hemoglobin_2DN2.pdb, Hb
cealign O2_Hb, Hb
color darksalmon, Hb
remove resn HOH and Hb
disable Hb

###--------color chains--------------

color marine, chain A and Hb
color lightblue, chain B and Hb
color palecyan, chain C and Hb
color cyan, chain D and Hb
=
color red, chain A and O2_Hb
color salmon, chain B and O2_Hb
color warmpink, chain C and O2_Hb
color chocolate, chain D and O2_Hb

color raspberry, chain A and Helix_*
color raspberry, chain B and  Helix2_*
color raspberry, chain C and Helix_*
color raspberry, chain D and Helix2_*

###--------subunit interfaces--------------

# create O2_Hb_alpha_alpha_interface (between chains A and C)
create pocket1, (byres(chain A within 3.6 of chain C) and O2_Hb)
create pocket2, (byres(chain C within 3.6 of chain A) and O2_Hb)
create O2_Hb_a_a_interface, pocket1 or pocket2
delete pocket*
color red, name O* and O2_Hb_a_a_interface
#color cyan, name C* and O2_Hb_a_a_interface
color blue, name N* and O2_Hb_a_a_interface
color yellow, name P* and O2_Hb_a_a_interface
color yellow, name S* and O2_Hb_a_a_interface
hide everything, O2_Hb_a_a_interface
show sticks, O2_Hb_a_a_interface

# create O2_Hb_alpha_beta_interface (between chains A and D)
create pocket1, (byres(chain A within 3.6 of chain D) and O2_Hb)
create pocket2, (byres(chain D within 3.6 of chain A) and O2_Hb)
create O2_Hb_a_b_interface, pocket1 or pocket2
delete pocket*
color red, name O* and O2_Hb_a_b_interface
#color cyan, name C* and O2_Hb_a_b_interface
color blue, name N* and O2_Hb_a_b_interface
color yellow, name P* and O2_Hb_a_b_interface
color yellow, name S* and O2_Hb_a_b_interface
hide everything, O2_Hb_a_b_interface
show sticks, O2_Hb_a_b_interface

# create Hb_alpha_alpha_interface (between chains A and C)
create pocket1, (byres(chain A within 3.6 of chain C) and Hb)
create pocket2, (byres(chain C within 3.6 of chain A) and Hb)
create Hb_a_a_interface, pocket1 or pocket2
delete pocket*
color red, name O* and Hb_a_a_interface
#color cyan, name C* and Hb_a_a_interface
color blue, name N* and Hb_a_a_interface
color yellow, name P* and Hb_a_a_interface
color yellow, name S* and Hb_a_a_interface
hide everything, Hb_a_a_interface
show sticks, Hb_a_a_interface


# create Hb_alpha_beta_interface (between chains A and D)
create pocket1, (byres(chain A within 3.6 of chain D) and Hb)
create pocket2, (byres(chain D within 3.6 of chain A) and Hb)
create Hb_a_b_interface, pocket1 or pocket2
delete pocket*
color red, name O* and Hb_a_b_interface
#color cyan, name C* and Hb_a_b_interface
color blue, name N* and Hb_a_b_interface
color yellow, name P* and Hb_a_b_interface
color yellow, name S* and Hb_a_b_interface
hide everything, Hb_a_b_interface
show sticks, Hb_a_b_interface

show spheres, (((resn thr and resi 41) or (resn thr and resi 38) or (resn pro and resn 44) or (resn his and resi 97) or (resn asp and resi 99)) and Hb_a_b_interface)
show spheres, (((resn thr and resi 41) or (resn thr and resi 38) or (resn pro and resn 44) or (resn his and resi 97) or (resn asp and resi 99)) and O2_Hb_a_b_interface)


# show the deoxy hemes with Fe
create de_hem1, resn hem and Hb
create de_his, ((resi 87 and resn his) or (resi 92 and resn his) and Hb)
create de_pocket, (((resi 43 or resi 58 or resi 62) and (chain A or chain C)) or ((resi 42 or resi 63 or resi 67) and (chain B or chain D)) and Hb)
create deoxy_heme, de_hem1 or de_his or de_pocket
delete de_hem1 or de_his or de_pocket
show sticks, deoxy_heme

### ---------
bond (heme or deoxy_heme) and resi 87 and name NE2 and chain A, (heme or deoxy_heme) and name fe and chain A
bond (heme or deoxy_heme) and name O1 and chain A, (heme or deoxy_heme) and name fe and chain A

bond (heme or deoxy_heme) and resi 92 and name NE2 and chain B, (heme or deoxy_heme) and name fe and chain B
bond (heme or deoxy_heme) and name O1 and chain B, (heme or deoxy_heme) and name fe and chain B

bond (heme or deoxy_heme) and resi 87 and name NE2 and chain C, (heme or deoxy_heme) and name fe and chain C
bond (heme or deoxy_heme) and name O1 and chain C, (heme or deoxy_heme) and name fe and chain C

bond (heme or deoxy_heme) and resi 92 and name NE2 and chain D, (heme or deoxy_heme) and name fe and chain D
bond (heme or deoxy_heme) and name O1 and chain D, (heme or deoxy_heme) and name fe and chain D

color orange, name fe and (heme or deoxy_heme)
color lightblue, name C* and deoxy_heme
color firebrick, name C* and heme
color blue, name N* and (heme or deoxy_heme)
color red, name O* and (heme or deoxy_heme)

remove resn hem and Hb
disable all
enable heme
enable O2_Hb
enable Helix*

### cut below here and paste into script ###
set_view (\
    -0.378467739,   -0.753544033,   -0.537518322,\
     0.458761007,    0.351658911,   -0.816008389,\
     0.803926110,   -0.555424571,    0.212605730,\
     0.000000000,    0.000000000, -190.794433594,\
    28.708375931,   28.692459106,    0.008205414,\
   150.423782349,  231.165084839,  -20.000000000 )
### cut above here and paste into script ###
